Skip to contents

Launch a Shiny app to allow interactive plotting of standardised stochastic data, burden estimates, impacts, comparisons between touchstones, and comparisons between modelling groups.

Usage

stochastic_explorer(data_dir = "//wpia-hn2.hpc.dide.ic.ac.uk/vimc_stochastics")

Arguments

data_dir

The location of the standardised stochastic folder hierarchy; this can be a local path, a fully-qualified network path on windows, or a mount point on linux or Mac.