Transform touchstone-relevant extracted data into tables ready for
database import. This should be called from the transform code of montagu-import,
calling stoner::stone_transform(extracted_data) with the same argument provided
to the montagu-import transform function.
Usage
stone_transform(extracted_data)
Arguments
The extracted data that was generated by the previous extract call
Value
A list of data frames, one for each table, with names matching the
database table names, and containing rows to be added to that table.
Details
For specific information on what steps the transform function does.
see the vignette.