Produce meta.csv summary of the structure and content of a standardised stochastic data folder.
Source: R/stochastic_files.R
stone_stochastic_make_meta.RdCreate a meta.csv file in the root of the standardised
stochastics. The columns contain scalars of touchstone,
disease, group, scenario - and for each row, a
semi-colon-separated lists for countries and outcomes.
This is useful for making the stochastic explorer faster
on startup (otherwise it has to sample all of the files
each time you run it) - and also it is a good general
record of all the stochastic data we have.